@@ -16,7 +16,7 @@ class DuplicatedRecord(ValidationError):
         self.engine = self._get_engine(integrity_error=self.integrity_error)
         self.constraints, self.values = self._parse_error()
 
-        model_name = {self.model.__class__.__name__}
+        model_name = self.model.__name__
         violation = " and ".join([f"{constraint}={value}" for constraint, value in zip(self.constraints, self.values)])
         message = f"A {model_name} with `{violation}` already exists."
         super().__init__(message=message, code=status.HTTP_409_CONFLICT)
