@@ -36,7 +36,7 @@ class UnplugSignal:
         self.stop()
 
 
-pre_soft_delete = Signal(providing_args=["instance"])
-post_soft_delete = Signal(providing_args=["instance"])
-pre_undelete = Signal(providing_args=["instance"])
-post_undelete = Signal(providing_args=["instance"])
+pre_soft_delete = Signal()
+post_soft_delete = Signal()
+pre_undelete = Signal()
+post_undelete = Signal()
