@@ -12,6 +12,8 @@ from drf_kit.views.viewsets import (
 
 
 class SingleNestedViewMixin(NestedViewMixin):
+    http_method_names = ModelViewSet.http_method_names + ["put"]
+
     def get_object(self):
         return self.filter_queryset(self.get_queryset()).first()
 
@@ -28,9 +30,7 @@ class SingleNestedViewMixin(NestedViewMixin):
         return super().partial_update(request, *args, **kwargs)
 
     def http_pk_not_allowed(self):
-        error = {
-            'error': "There's no need to provide a PK since there's no more than 1 object"
-        }
+        error = {"error": "There's no need to provide a PK since there's no more than 1 object"}
         return Response(
             data=error,
             status=status.HTTP_405_METHOD_NOT_ALLOWED,
@@ -40,10 +40,7 @@ class SingleNestedViewMixin(NestedViewMixin):
     def create(self, request, **kwargs):
         instance = self.get_object()
         if instance:
-            error = {
-                'error': "Already exists and only one is allowed."
-                         " Use PUT to override existing relationship."
-            }
+            error = {"error": "Already exists and only one is allowed." " Use PUT to override existing relationship."}
             return Response(status=status.HTTP_409_CONFLICT, data=error)
 
         return super().create(request, **kwargs)
@@ -64,6 +61,28 @@ class SingleNestedViewMixin(NestedViewMixin):
         # Makes the collection behave as a single object
         return self.partial_update(request, *args, **kwargs)
 
+    def put(self, request, *args, **kwargs):
+        # New verb PUT used as default for collections
+        # Makes the collection behave as a single object
+        # and removes the previous before adding a new one
+        if self.detail:
+            return self.http_pk_not_allowed()
+        instance = self.get_object()
+        if instance:
+            instance.delete()
+            status_code = status.HTTP_200_OK
+        else:
+            status_code = status.HTTP_201_CREATED
+
+        # Pretty similar to .create, but with dynamic status code
+        serializer = self.get_serializer(data=request.data)
+        serializer.is_valid(raise_exception=True)
+        obj = self.perform_create(serializer)
+        headers = self.get_success_headers(serializer.data)
+
+        data = self.get_response_serializer(obj).data
+        return Response(data, status=status_code, headers=headers)
+
 
 class SingleNestedModelViewSet(SingleNestedViewMixin, ModelViewSet):
     pass
